@@ -90,7 +90,8 @@ static const GOptionEntry entries[] = {
 static void 
 destroy_dialog (GtkWidget *widget, gpointer data )
 {
-        gtk_main_quit ();
+	if (gtk_main_level () > 0)
+		gtk_main_quit ();
 }
 
 static char *
@@ -528,7 +529,7 @@ update_button_image (GtkSettings *settings,
 		gtk_widget_show (widget);
 }
 
-static void
+static NS_ui *
 nautilus_sendto_create_ui (void)
 {
 	GtkBuilder *app;
@@ -538,6 +539,7 @@ nautilus_sendto_create_ui (void)
 	gboolean supports_dirs;
 	GtkSettings *gtk_settings;
 	GtkWidget *button_image;
+	int last_compress;
 
 	app = gtk_builder_new ();
 	if (!gtk_builder_add_from_file (app, UIDIR "/" "nautilus-sendto.ui", &error))	{
@@ -579,9 +581,8 @@ nautilus_sendto_create_ui (void)
 			  G_CALLBACK (update_button_image), button_image);
 	update_button_image (gtk_settings, NULL, button_image);
 
-	gtk_combo_box_set_active (GTK_COMBO_BOX(ui->pack_combobox),
-				  g_settings_get_int (settings,
-						      NAUTILUS_SENDTO_LAST_COMPRESS));
+	last_compress = g_settings_get_int (settings, NAUTILUS_SENDTO_LAST_COMPRESS);
+	gtk_combo_box_set_active (GTK_COMBO_BOX(ui->pack_combobox), last_compress);
 
 	if (file_list != NULL && file_list->next != NULL)
 		one_file = FALSE;
@@ -638,7 +639,7 @@ nautilus_sendto_create_ui (void)
 		gtk_widget_set_sensitive (ui->pack_checkbutton, FALSE);
 	}
 
-	gtk_widget_show (ui->dialog);
+	return ui;
 }
 
 static void
@@ -809,6 +810,7 @@ int main (int argc, char **argv)
 {
 	GOptionContext *context;
 	GError *error = NULL;
+	NS_ui *ui;
 
 	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
@@ -846,7 +848,8 @@ int main (int argc, char **argv)
 		gtk_dialog_run (GTK_DIALOG (error_dialog));
 		return 1;
 	}
-	nautilus_sendto_create_ui ();
+	ui = nautilus_sendto_create_ui ();
+	gtk_widget_show (ui->dialog);
 
 	gtk_main ();
 	g_object_unref(settings);
